#!/usr/bin/env python

from twitter.api import Twitter, TwitterError
from twitter.oauth import OAuth, write_token_file, read_token_file
from twitter.oauth_dance import oauth_dance
from twitter.api import TwitterHTTPError

from settings import TWITTER_CONSUMER_KEY, TWITTER_CONSUMER_SECRET, \
                   TWITTER_OAUTH_TOKEN, TWITTER_OAUTH_TOKEN_SECRET, \
                   LANGUAGE_CODE, KEYWORDS


class TwitterCrawler():

    def __init__(self):
        auth_instance = OAuth(TWITTER_OAUTH_TOKEN, TWITTER_OAUTH_TOKEN_SECRET,
                              TWITTER_CONSUMER_KEY, TWITTER_CONSUMER_SECRET)
        self.connection = Twitter(auth=auth_instance, secure=True)
        self.keywords = KEYWORDS

    def search(self, keywords=[]):
        """
        search Twitter for tweets containing keywords
        by default, search for keywords in settings.py
        if passed keywords as first arg, search using the explicitly
        passed keywords
        """
        if not self.keywords and not keywords:
            raise Exception("Must have KEYWORDS in settings or pass keywords\
                     as first arg ['ball','bat'] specified")
        if not keywords:
            keywords = KEYWORDS
        search_str = ' '.join(keywords) if keywords else ' '.join(self.keywords)
        try:
            search_results = self.connection.search(q="%s" % (search_str))
        except TwitterHTTPError as e:
            raise e
        tweets = []
        for result in search_results['results']:
            if result['iso_language_code'] != LANGUAGE_CODE:
                    continue
            relevance = self.is_relevent(result['text'], keywords)
            if relevance:
                result['rank'] = relevance
                tweets.append(result)
        return tweets

    def is_relevent(self, tweet, keywords, rank_minimum=1):
        """
        determine if a tweet_message is relevant based on criteria
        give back relevent rank score
        """
        rank = self.tweet_rank(tweet, keywords)
        if rank >= rank_minimum:
            return rank
        else:
            return 0

    def tweet_rank(self, tweet, keywords):
        """
        TODO: Implement misspelling, better pattern matching
        Currently, just checks for keywords in tweet
        """
        clean_tweet = tweet.lower().strip()
        rank = 0
        for keyword in keywords:
            if keyword in clean_tweet:
                rank += 1
        return rank



