import os
import time
import sys
import urllib
import simplejson
import sqlite3

from crawlers.twitter_crawler import TwitterCrawler
from settings import DAEMON_REFRESH_SPEED, DATABASE


class CrawlerDaemon():
    def __init__(self, crawler, database_instance=None):
        """
        pass crawler instance as first arg
        """
        self.crawler = crawler
        self.db = database_instance if database_instance \
                   else self.sqlite_handler()

    def sql_dump(self, results):
        """
        dump crawler results to sql database
        """
        for result in results:
            sql = "INSERT INTO messages \
                  ('from_user','message','rank') VALUES \
                  (?,?,?)"
            self.db.execute(sql, (result['from_user'],
                            result['text'], result['rank']))
            self.conn.commit()
        return True

    def sqlite_handler(self):
        """
        sqlite handler to local file
        """
        conn = sqlite3.connect(DATABASE)
        cursor = conn.cursor()
        with open('schema.sql', 'r') as schema:
            # can only execute one statement at a time
            schema_content = ''.join(schema.read().splitlines())
            sql_statements = schema_content.split(';')
            for sql in sql_statements:
                cursor.execute(sql)
                conn.commit()
        self.conn = conn
        return cursor

    def run(self, daemonize=True):
        """
        Populate results database with crawler results
        """
        if not daemonize:
            return self.sql_dump(self.crawler.search())
        while True:
            try:
                self.sql_dump(self.crawler.search())
            except (KeyboardInterrupt, SystemExit):
                print 'Interrupt signal received'
                break
            time.sleep(int(DAEMON_REFRESH_SPEED))


if __name__ == '__main__':
    twitter_daemon = CrawlerDaemon(TwitterCrawler())
    twitter_daemon.run()

