from flask import Flask
from sqlite3 import dbapi2 as sqlite3
from contextlib import closing
from flask import Flask, request, session, g, render_template, jsonify
import argparse
import os

from settings import DATABASE


app = Flask(__name__)
app.config.from_object('settings')
app.debug = app.config['DEBUG']


def connect_db():
    """Returns a new connection to the database."""
    return sqlite3.connect(app.config['DATABASE'])

def init_db():
    """Creates the database tables."""
    with closing(connect_db()) as db:
        with app.open_resource('schema.sql') as f:
            db.cursor().executescript(f.read())
        db.commit()

@app.before_request
def before_request():
    """Make sure we are connected to the database each request."""
    g.db = connect_db()

@app.teardown_request
def teardown_request(exception):
    """Closes the database again at the end of the request."""
    if hasattr(g, 'db'):
        g.db.close()

def fetch_tweets():
    cur = g.db.execute('select from_user, message, rank \
                       from messages order by id desc')
    tweets = [dict(from_user=row[0],message=row[1],
              rank=row[2]) for row in cur.fetchall()]
    return tweets

@app.route('/getTweets')
def get_tweets():
    format = request.args.get('format', 'html')
    tweets = fetch_tweets()
    if format == 'html':
        return render_template('get_tweets.html', tweets=tweets)
    elif format == 'json':
        return jsonify(results=tweets)
    else:
        return render_template('get_tweets.html', alert='Invalid format')

@app.route('/')
def show_tweets():
    tweets = fetch_tweets()
    return render_template('show_tweets.html', tweets=tweets)


if __name__ == "__main__":
    import threading
    from daemons import CrawlerDaemon
    from crawlers.twitter_crawler import TwitterCrawler
    if not os.path.isfile('schema.sql') or not os.path.isfile('results.db'):
        init_db()
    class ThreadClass(threading.Thread):
        def run(self):
            daemon = CrawlerDaemon(TwitterCrawler())
            daemon.run()
    t = ThreadClass()
    t.setDaemon(True)
    t.start()
    app.run()
