import unittest
import urllib
import os
import sys
import shutil


class TestDaemon(unittest.TestCase):

    def setUp(self):
        """
        Initialize Twitter Crawler instance
        """
        try:
            open('../schema.sql','r')
        except IOError as e:
            raise Exception('schema.sql file does not exist.\
                   run the daemon or server first')
        shutil.copy('../schema.sql', 'schema.sql')
        try:
            open('../results.db','r')
        except IOError as e:
            raise Exception('results.db file does not exist.\
                   run the daemon or server first and let results\
                   populate')
        shutil.copy('../results.db', 'results.db')
        from crawlers.twitter_crawler import TwitterCrawler
        from daemons import CrawlerDaemon
        self.daemon = CrawlerDaemon(TwitterCrawler())

    def test_database_connection(self):
        """
        test that we can connect to database
        """
        self.assertTrue(self.daemon.db)

    def test_daemon_db_dump(self):
        """
        test that we can run the daemon and retrieve
        dumped daemon data
        """
        # at this point, schema and results db should be generated
        self.assertTrue(os.path.isfile('schema.sql'))
        self.assertTrue(os.path.isfile('results.db'))
        self.daemon.run(daemonize=False)
        # check that data was dumped to db
        self.daemon.db.execute("SELECT * FROM messages")
        self.assertTrue(self.daemon.db.fetchone())

    def tearDown(self):
        os.remove('schema.sql')
        os.remove('results.db')

if __name__ == '__main__':
    # can't use relative parent imports if script called as main
    # so append parent directory to path
    parent_dir = os.path.normpath(os.path.join(os.getcwd(), '..'))
    sys.path.append(parent_dir)
    unittest.main()
