import unittest
import urllib
import os
import sys


class TestTwitterCrawler(unittest.TestCase):

    def setUp(self):
        """
        Initialize Twitter Crawler instance
        """
        from crawlers.twitter_crawler import TwitterCrawler
        self.twitter_crawler = TwitterCrawler()

    def test_twitter_api_connection(self):
        """
        test that we can connect to twitter
        """
        self.assertTrue(self.twitter_crawler.connection)

    def test_twitter_search_keywords(self):
        """
        test that we can search twitter using passed keywords
        """
        keywords = ['ball']
        results = self.twitter_crawler.search(keywords)
        self.assertTrue(results)
        keywords = ['sfiosjfiaejowetjeoitjetiejtieotjlfdasjfkljdslakfjlfj']
        results = self.twitter_crawler.search(keywords)
        self.assertFalse(results)

    def test_twitter_is_relevent(self):
        """
        test that we can determine tweet relevance using
        is_relevant mathing rules
        """
        tweet = 'I can has cheezeburger'
        keywords = ['ball']
        self.assertFalse(self.twitter_crawler.is_relevent(tweet,
                                                          keywords))
        keywords = ['cheezeburger']
        self.assertTrue(self.twitter_crawler.is_relevent(tweet,
                                                         keywords))
        keywords = ['cheeze']
        self.assertTrue(self.twitter_crawler.is_relevent(tweet,
                                                         keywords))
        keywords = ['cheeze', 'burger']
        self.assertTrue(self.twitter_crawler.is_relevent(tweet,
                                                         keywords))

    def test_twitter_tweet_rank(self):
        """
        test that we can rank tweets by default
        tweet_rank behavior
        """
        tweet = 'I can has cheezeburger'
        keywords = ['ball']
        rank = self.twitter_crawler.tweet_rank(tweet, keywords)
        self.assertEqual(rank, 0, 'Incorrect rank value')
        keywords = ['cheeze']
        rank = self.twitter_crawler.tweet_rank(tweet, keywords)
        self.assertEqual(rank, 1, 'Incorrect rank value')
        keywords = ['cheeze', 'has']
        rank = self.twitter_crawler.tweet_rank(tweet, keywords)
        self.assertEqual(rank, 2, 'Incorrect rank value')

if __name__ == '__main__':
    # can't use relative parent imports if script called as main
    # so append parent directory to path
    parent_dir = os.path.normpath(os.path.join(os.getcwd(), '..'))
    sys.path.append(parent_dir)
    unittest.main()

