import unittest
import urllib2
import os
import sys
import shutil
import subprocess


class TestServer(unittest.TestCase):

    def setUp(self):
        """
        Initialize Server
        """
        try:
            open('../schema.sql','r')
        except IOError as e:
            raise Exception('schema.sql file does not exist.\
                   run the daemon or server first')
        shutil.copy('../schema.sql', 'schema.sql')
        try:
            open('../results.db','r')
        except IOError as e:
            raise Exception('results.db file does not exist.\
                   run the daemon or server first and let results\
                   populate')
        shutil.copy('../results.db', 'results.db')
        self.server = subprocess.Popen(["python", "../server.py"])
        self.base_url = 'http://127.0.0.1:5000/'
        self.connect_timeout = 5

    def send_http_get(self, params=''):
        response = urllib2.urlopen("%s%s" % (self.base_url, params),
                                   timeout=self.connect_timeout)
        return response

    def test_main_page(self):
        """
        Test that we can render the main template
        """
        response = self.send_http_get('/').read()
        self.assertTrue('<!DOCTYPE html>' in response)

    def test_get_tweets_format_html(self):
        """
        Test that we can render get_tweets method in html
        """
        response = self.send_http_get('/getTweets?format=html').read()
        self.assertTrue('id="tweets"' in response)

    def test_get_tweets_format_html(self):
        """
        Test that we can render get_tweets method in html
        """
        response = self.send_http_get('/getTweets?format=json').read()
        self.assertTrue('"results": [' in response)

    def tearDown(self):
        os.remove('schema.sql')
        os.remove('results.db')
        self.server.kill()


if __name__ == '__main__':
    # can't use relative parent imports if script called as main
    # so append parent directory to path
    parent_dir = os.path.normpath(os.path.join(os.getcwd(), '..'))
    sys.path.append(parent_dir)
    unittest.main()
